@@ -1,35 +1,37 @@
-#include <ompl/geometric/PathGeometric.h>
-#include <ompl/tools/lightning/LightningDB.h>
 #include <pybind11/functional.h>
 #include <pybind11/pybind11.h>
 #include <pybind11/stl.h>
 
-#include <memory>
-#include <vector>
-
-#include "ompl/base/spaces/RealVectorStateSpace.h"
-#include "ompl/util/RandomNumbers.h"
-#include "ompl_higher.hpp"
+#include "higher.hpp"
 
 namespace py = pybind11;
 
-void setGlobalSeed(size_t seed) { ompl::RNG::setSeed(seed); }
-
-namespace ob = ompl::base;
-namespace og = ompl::geometric;
-namespace ot = ompl::tools;
-
 PYBIND11_MODULE(_omplpy, m)
 {
   m.doc() = "unofficial ompl python wrapper";
   m.def("set_random_seed", &setGlobalSeed);
+
+  py::class_<ConstrainedPlanner>(m, "_ConstrainedPlanner")
+      .def(py::init<const ConstFn&,
+                    const ConstJacFn&,
+                    std::vector<double>,
+                    std::vector<double>,
+                    std::function<bool(std::vector<double>)>,
+                    size_t,
+                    std::vector<double>,
+                    std::string,
+                    std::optional<double>>())
+      .def("reset_is_valid", &ConstrainedPlanner::resetIsValid)
+      .def("solve", &ConstrainedPlanner::solve);
+
   py::class_<OMPLPlanner>(m, "_OMPLPlanner")
       .def(py::init<std::vector<double>,
                     std::vector<double>,
                     std::function<bool(std::vector<double>)>,
                     size_t,
                     std::vector<double>,
-                    std::string>())
+                    std::string,
+                    std::optional<double>>())
       .def("reset_is_valid", &OMPLPlanner::resetIsValid)
       .def("solve", &OMPLPlanner::solve);
 
@@ -48,7 +50,20 @@ PYBIND11_MODULE(_omplpy, m)
                     std::function<bool(std::vector<double>)>,
                     size_t,
                     std::vector<double>,
-                    std::string>())
+                    std::string,
+                    std::optional<double>>())
       .def("reset_is_valid", &LightningPlanner::resetIsValid)
       .def("solve", &LightningPlanner::solve);
+
+  py::class_<LightningRepairPlanner>(m, "_LightningRepairPlanner")
+      .def(py::init<std::vector<double>,
+                    std::vector<double>,
+                    std::function<bool(std::vector<double>)>,
+                    size_t,
+                    std::vector<double>,
+                    std::string,
+                    std::optional<double>>())
+      .def("reset_is_valid", &LightningRepairPlanner::resetIsValid)
+      .def("solve", &LightningRepairPlanner::solve)
+      .def("set_heuristic", &LightningRepairPlanner::set_heuristic);
 }
